---
title: 결제대행사 가입시 위험 업종 유형
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 결제대행사 가입시 위험 업종 유형
  description: >-
    결제대행사 계약을 위해 온라인결제로 판매되는 서비스(상품) 유형을 1차적으로 가맹점이 심사하여 입점을 결정합니다. 등록불가업종이 아니어도
    PG사에서 결제사고가 빈번했던 서비스 형태나 판매방식은 입점(가입)이 거절될 수 있습니다.
  keywords:
    - 공통
    - 결제대행사 계약
    - PG 계약
    - 위험 업종
tags:
  - 공통
  - 결제대행사 계약
pgCompanies:
  - 공통
searchTags:
  - 위험업종
  - RM기준
  - 업종심사
  - 심사반려
  - 입점심사
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="PG 계약을 위해서는 온라인 결제 시 판매하는 서비스(상품) 유형을 
1차적으로 심사를 하고 입점 가능 여부가 결정됩니다." />

### **결제대행사 입점이 어려운 업종 유형**

아래와 같은 등록 불가 업종이 아니더라도 PG 사에서 운영 시 경험적으로 결제 사고가 빈번했던 서비스 형태나 판매 방식을 기준으로 입점(가입)을 거절할 수도 있습니다.

또한 카드사 및 PG사 등록 불가 기준은 사회적 이슈 등에 따라 리스크가 반영되어 수시로 변경될 수 있습니다.

- [업종별 결제대행사 입점기준 보러가기 ↗](https://guide.portone.io/6a3b9369-19ab-491b-822c-58d2f4a6fddf?_gl=1*aj7v3y*_gcl_au*MTgzMjI2MDUzNS4xNzM5NzczNDQ3*_ga*MTAyNDQzNjI1MC4xNzM5NzczNDQ3*_ga_PD0FDL16NZ*MTc0MDAzMzgwMS43LjEuMTc0MDAzODIxNi41My4wLjA.)
- [카드사 등록불가 업종 (KG이니시스 제공) 보러 가기 ↗](https://www.inicis.com/service-application)
- 사전 PG입점 가능여부 체크가 필요하실 경우 서비스 필수구축요건 체크 후 포트원 1:1채팅문의 \
  [채널톡 문의](https://x06k7.channel.io/lounge) | [카카오톡 문의](http://pf.kakao.com/_nlHxcu/chat) 또는 <cs@portone.io> 로 문의 주시기 바랍니다.
- 네이버페이 입점제한 기준 : [네이버페이 취급제한 상품 보러 가기 ↗](https://admin.pay.naver.com/introduction/restricted) 참고

<Callout content="- 구매자의 결제 요청 시점과 실제 결제 실행 시점이 다른 경우 (ex. 크라우드 펀딩)
- 거래 대상이 이용권 형태의 경우 (선결제는 했지만 서비스의 이행이 불확실함)
- 포인트로 충전 후 현금으로 환전(출금) 하는 경우 (카드깡으로 형태로 변질되는 리스크 발생)
- 비상시적으로 큰 거래가 발생하거나 일괄적인 취소가 발생되는 경우 (ex. 콘서트 : 우천 시 등 대규모 취소/환불 가능성, 크라우드 펀딩 : 목표 미달성시 일괄 취소 등)" icon="💡" title="입점이 어려운 대표 사례" />

### **업종에 따른 결제대행사별 입점가능여부 참고**

위 대표 사례와 같이 위험업종에 해당되는 경우 여러 다른 방안을 모색해 보실 수 있습니다.

- 입점 제한을 피하기 위하여 'BM' 변경
- 구매자의 결제 취소율을 낮출 수 있는 방법 모색
- PG사와 협의를 통해 보증보험 가입 기준을 높이기

결제대행사별로 업종에 따른 입점 가능 여부 기준이 상이하기 때문에, 포트원에서 제공 드리는 위험업종과 그에 따른 결제대행사 지원 · 검토 가능 여부를 안내드리오니 자세한 사항은 아래 가이드를 참고해 주시기 바랍니다.

<Callout title="업종별 결제대행사 입점기준 보러가기 ↗" icon="" />
